pub struct CTickingStep {
pub tick_steps: i32,
}Expand description
Packet sent to clients to inform them of the number of frozen ticks to run. This is used when stepping forward while the server is frozen.
Fields
tick_steps: i32The number of ticks to step forward.
Implementations